==> sharyn-10.10.0.tgz: package/redux/async-map-reductions.test.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _compose = _interopRequireDefault(require("recompose/compose"));

var _asyncMapReductions = require("./async-map-reductions");

test('asyncMapSetTrueReduction', function () {
  expect((0, _asyncMapReductions.asyncMapSetTrueReduction)('a')({})).toEqual({
    a: true
  });
  expect((0, _compose.default)((0, _asyncMapReductions.asyncMapSetTrueReduction)('a'))({})).toEqual({
    a: true
  });
});
test('asyncMapSetPageTrueReduction', function () {
  expect((0, _asyncMapReductions.asyncMapSetPageTrueReduction)()({})).toEqual({
    page: true
  });
  expect((0, _compose.default)((0, _asyncMapReductions.asyncMapSetPageTrueReduction)())({})).toEqual({
    page: true
  });
});
test('asyncMapSetTrueReductionFromAsyncKeyProp', function () {
  expect((0, _asyncMapReductions.asyncMapSetTrueReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  })({})).toEqual({
    a: true
  });
  expect((0, _compose.default)((0, _asyncMapReductions.asyncMapSetTrueReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  }))({})).toEqual({
    a: true
  });
});
test('asyncMapSetRequestReduction', function () {
  expect((0, _asyncMapReductions.asyncMapSetRequestReduction)('a')({})).toEqual({
    a: _asyncMapReductions.REQUEST
  });
  expect((0, _compose.default)((0, _asyncMapReductions.asyncMapSetRequestReduction)('a'))({})).toEqual({
    a: _asyncMapReductions.REQUEST
  });
});
test('asyncMapSetRequestReductionFromAsyncKeyProp', function () {
  expect((0, _asyncMapReductions.asyncMapSetRequestReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  })({})).toEqual({
    a: _asyncMapReductions.REQUEST
  });
  expect((0, _compose.default)((0, _asyncMapReductions.asyncMapSetRequestReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  }))({})).toEqual({
    a: _asyncMapReductions.REQUEST
  });
});
test('asyncMapSetSuccessReduction', function () {
  expect((0, _asyncMapReductions.asyncMapSetSuccessReduction)('a')({})).toEqual({
    a: _asyncMapReductions.SUCCESS
  });
  expect((0, _compose.default)((0, _asyncMapReductions.asyncMapSetSuccessReduction)('a'))({})).toEqual({
    a: _asyncMapReductions.SUCCESS
  });
});
test('asyncMapSetSuccessReductionFromAsyncKeyProp', function () {
  expect((0, _asyncMapReductions.asyncMapSetSuccessReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  })({})).toEqual({
    a: _asyncMapReductions.SUCCESS
  });
  expect((0, _compose.default)((0, _asyncMapReductions.asyncMapSetSuccessReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  }))({})).toEqual({
    a: _asyncMapReductions.SUCCESS
  });
});
test('asyncMapSetFailureReduction', function () {
  expect((0, _asyncMapReductions.asyncMapSetFailureReduction)('a')({})).toEqual({
    a: _asyncMapReductions.FAILURE
  });
  expect((0, _compose.default)((0, _asyncMapReductions.asyncMapSetFailureReduction)('a'))({})).toEqual({
    a: _asyncMapReductions.FAILURE
  });
});
test('asyncMapSetFailureReductionFromAsyncKeyProp', function () {
  expect((0, _asyncMapReductions.asyncMapSetFailureReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  })({})).toEqual({
    a: _asyncMapReductions.FAILURE
  });
  expect((0, _compose.default)((0, _asyncMapReductions.asyncMapSetFailureReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  }))({})).toEqual({
    a: _asyncMapReductions.FAILURE
  });
});
test('asyncMapSetCustomReductionFromProps', function () {
  expect((0, _asyncMapReductions.asyncMapSetCustomReductionFromProps)({
    asyncKey: 'a',
    asyncValue: 'custom'
  })({})).toEqual({
    a: 'custom'
  });
  expect((0, _compose.default)((0, _asyncMapReductions.asyncMapSetCustomReductionFromProps)({
    asyncKey: 'a',
    asyncValue: 'custom'
  }))({})).toEqual({
    a: 'custom'
  });
});
test('asyncMapDeleteReduction', function () {
  var s = {
    foo: 'foo',
    bar: 'bar'
  };
  expect((0, _asyncMapReductions.asyncMapDeleteReduction)('foo')(s)).toEqual({
    bar: 'bar'
  });
  expect((0, _compose.default)((0, _asyncMapReductions.asyncMapDeleteReduction)('foo'))(s)).toEqual({
    bar: 'bar'
  });
});
test('asyncMapDeletePageReduction', function () {
  var s = {
    page: 'page',
    bar: 'bar'
  };
  expect((0, _asyncMapReductions.asyncMapDeletePageReduction)()(s)).toEqual({
    bar: 'bar'
  });
  expect((0, _compose.default)((0, _asyncMapReductions.asyncMapDeletePageReduction)())(s)).toEqual({
    bar: 'bar'
  });
});
test('asyncMapDeleteReductionFromAsyncKeyProp', function () {
  var s = {
    foo: 'foo',
    bar: 'bar'
  };
  expect((0, _asyncMapReductions.asyncMapDeleteReductionFromAsyncKeyProp)({
    asyncKey: 'foo'
  })(s)).toEqual({
    bar: 'bar'
  });
  expect((0, _compose.default)((0, _asyncMapReductions.asyncMapDeleteReductionFromAsyncKeyProp)({
    asyncKey: 'foo'
  }))(s)).toEqual({
    bar: 'bar'
  });
});
test('asyncMapClearExceptPageReduction', function () {
  var s = {
    page: 'page',
    foo: 'foo'
  };
  expect((0, _asyncMapReductions.asyncMapClearExceptPageReduction)()(s)).toEqual({
    page: 'page'
  });
  expect((0, _compose.default)((0, _asyncMapReductions.asyncMapClearExceptPageReduction)())(s)).toEqual({
    page: 'page'
  });
});

==> sharyn-11.8.0.tgz: package/redux/async-map-reductions.test.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _compose = _interopRequireDefault(require("recompose/compose"));

var _asyncMapReductions = require("./async-map-reductions");

test('asyncMapSetTrueReduction', function () {
  expect((0, _asyncMapReductions.asyncMapSetTrueReduction)('a')({})).toEqual({
    a: true
  });
  expect((0, _compose["default"])((0, _asyncMapReductions.asyncMapSetTrueReduction)('a'))({})).toEqual({
    a: true
  });
});
test('asyncMapSetPageTrueReduction', function () {
  expect((0, _asyncMapReductions.asyncMapSetPageTrueReduction)()({})).toEqual({
    page: true
  });
  expect((0, _compose["default"])((0, _asyncMapReductions.asyncMapSetPageTrueReduction)())({})).toEqual({
    page: true
  });
});
test('asyncMapSetTrueReductionFromAsyncKeyProp', function () {
  expect((0, _asyncMapReductions.asyncMapSetTrueReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  })({})).toEqual({
    a: true
  });
  expect((0, _compose["default"])((0, _asyncMapReductions.asyncMapSetTrueReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  }))({})).toEqual({
    a: true
  });
});
test('asyncMapSetRequestReduction', function () {
  expect((0, _asyncMapReductions.asyncMapSetRequestReduction)('a')({})).toEqual({
    a: _asyncMapReductions.REQUEST
  });
  expect((0, _compose["default"])((0, _asyncMapReductions.asyncMapSetRequestReduction)('a'))({})).toEqual({
    a: _asyncMapReductions.REQUEST
  });
});
test('asyncMapSetRequestReductionFromAsyncKeyProp', function () {
  expect((0, _asyncMapReductions.asyncMapSetRequestReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  })({})).toEqual({
    a: _asyncMapReductions.REQUEST
  });
  expect((0, _compose["default"])((0, _asyncMapReductions.asyncMapSetRequestReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  }))({})).toEqual({
    a: _asyncMapReductions.REQUEST
  });
});
test('asyncMapSetSuccessReduction', function () {
  expect((0, _asyncMapReductions.asyncMapSetSuccessReduction)('a')({})).toEqual({
    a: _asyncMapReductions.SUCCESS
  });
  expect((0, _compose["default"])((0, _asyncMapReductions.asyncMapSetSuccessReduction)('a'))({})).toEqual({
    a: _asyncMapReductions.SUCCESS
  });
});
test('asyncMapSetSuccessReductionFromAsyncKeyProp', function () {
  expect((0, _asyncMapReductions.asyncMapSetSuccessReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  })({})).toEqual({
    a: _asyncMapReductions.SUCCESS
  });
  expect((0, _compose["default"])((0, _asyncMapReductions.asyncMapSetSuccessReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  }))({})).toEqual({
    a: _asyncMapReductions.SUCCESS
  });
});
test('asyncMapSetFailureReduction', function () {
  expect((0, _asyncMapReductions.asyncMapSetFailureReduction)('a')({})).toEqual({
    a: _asyncMapReductions.FAILURE
  });
  expect((0, _compose["default"])((0, _asyncMapReductions.asyncMapSetFailureReduction)('a'))({})).toEqual({
    a: _asyncMapReductions.FAILURE
  });
});
test('asyncMapSetFailureReductionFromAsyncKeyProp', function () {
  expect((0, _asyncMapReductions.asyncMapSetFailureReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  })({})).toEqual({
    a: _asyncMapReductions.FAILURE
  });
  expect((0, _compose["default"])((0, _asyncMapReductions.asyncMapSetFailureReductionFromAsyncKeyProp)({
    asyncKey: 'a'
  }))({})).toEqual({
    a: _asyncMapReductions.FAILURE
  });
});
test('asyncMapSetCustomReductionFromProps', function () {
  expect((0, _asyncMapReductions.asyncMapSetCustomReductionFromProps)({
    asyncKey: 'a',
    asyncValue: 'custom'
  })({})).toEqual({
    a: 'custom'
  });
  expect((0, _compose["default"])((0, _asyncMapReductions.asyncMapSetCustomReductionFromProps)({
    asyncKey: 'a',
    asyncValue: 'custom'
  }))({})).toEqual({
    a: 'custom'
  });
});
test('asyncMapDeleteReduction', function () {
  var s = {
    foo: 'foo',
    bar: 'bar'
  };
  expect((0, _asyncMapReductions.asyncMapDeleteReduction)('foo')(s)).toEqual({
    bar: 'bar'
  });
  expect((0, _compose["default"])((0, _asyncMapReductions.asyncMapDeleteReduction)('foo'))(s)).toEqual({
    bar: 'bar'
  });
});
test('asyncMapDeletePageReduction', function () {
  var s = {
    page: 'page',
    bar: 'bar'
  };
  expect((0, _asyncMapReductions.asyncMapDeletePageReduction)()(s)).toEqual({
    bar: 'bar'
  });
  expect((0, _compose["default"])((0, _asyncMapReductions.asyncMapDeletePageReduction)())(s)).toEqual({
    bar: 'bar'
  });
});
test('asyncMapDeleteReductionFromAsyncKeyProp', function () {
  var s = {
    foo: 'foo',
    bar: 'bar'
  };
  expect((0, _asyncMapReductions.asyncMapDeleteReductionFromAsyncKeyProp)({
    asyncKey: 'foo'
  })(s)).toEqual({
    bar: 'bar'
  });
  expect((0, _compose["default"])((0, _asyncMapReductions.asyncMapDeleteReductionFromAsyncKeyProp)({
    asyncKey: 'foo'
  }))(s)).toEqual({
    bar: 'bar'
  });
});
test('asyncMapClearExceptPageReduction', function () {
  var s = {
    page: 'page',
    foo: 'foo'
  };
  expect((0, _asyncMapReductions.asyncMapClearExceptPageReduction)()(s)).toEqual({
    page: 'page'
  });
  expect((0, _compose["default"])((0, _asyncMapReductions.asyncMapClearExceptPageReduction)())(s)).toEqual({
    page: 'page'
  });
});
